@@ -368,10 +368,14 @@ def writeCalibFile():
     """
     pass
 
-def readCalibParametersInFile(openfile, Dict_to_update=None):
+def readCalibParametersInFile(openfile, Dict_to_update=None, guessCCDLabel=True):
     """
     read .det file (detector geometry calibration)
 
+    .. warning:: if CCDLabel is unknown, it is gueesed from pixelsize...
+
+    .. todo:: we could add dimensions to guess CCDLabel
+
     return dict of parameters in open file
     """
     #CCD_CALIBRATION_PARAMETERS = ["dd", "xcen", "ycen", "xbet", "xgam",
@@ -408,15 +412,18 @@ def readCalibParametersInFile(openfile, Dict_to_update=None):
 
     if 'CCDLabel' not in CCDcalib:  #will recognise from pixelsize...
         CCDcalib['CCDLabel'] = None# DEFAULT_CCDLABEL
-        if 'pixelsize' in CCDcalib:
-            ps = CCDcalib['pixelsize']
-            if abs(ps-0.0795) < 0.004:
-                ccdlabel = 'MARCCD165'
-            elif abs(ps-0.073) <= 0.002:
-                ccdlabel = 'sCMOS'
-            elif abs(ps-0.075) <= 0.002:
-                ccdlabel = 'psl_weiwei'
-            CCDcalib['CCDLabel'] = ccdlabel
+        if guessCCDLabel:
+            if 'pixelsize' in CCDcalib:
+                ps = CCDcalib['pixelsize']
+                if abs(ps-0.0795) < 0.004:
+                    ccdlabel = 'MARCCD165'
+                elif abs(ps-0.073) <= 0.002:
+                    ccdlabel = 'sCMOS'
+                elif abs(ps-0.075) <= 0.002:
+                    ccdlabel = 'psl_weiwei'
+                elif abs(ps-0.031) <= 0.002:
+                    ccdlabel = 'VHR_Feb13'
+                CCDcalib['CCDLabel'] = ccdlabel
 
     return CCDcalib
 
@@ -512,9 +519,9 @@ def writefile_Peaklist(outputprefixfilename, Data_array, overwrite=1,
     # just one row!
     elif len(Data_array.shape) == 1:
         print("single peak to record!")
-        longueur, nbcolumns = 1, Data_array.shape[0]
+        nbpeaks, nbcolumns = 1, Data_array.shape[0]
     else:
-        longueur, nbcolumns = Data_array.shape
+        nbpeaks, nbcolumns = Data_array.shape
         if Data_array.shape == (1, 10):
             Data_array = Data_array[0]
 
@@ -526,7 +533,7 @@ def writefile_Peaklist(outputprefixfilename, Data_array, overwrite=1,
     if outputfilename in os.listdir(os.curdir) and not overwrite:
         outputfilename = outputfilename + "_new" + ".dat"
 
-    if longueur == 1:
+    if nbpeaks == 1:
         Data_array = np.array([Data_array, Data_array])
 
 
@@ -538,12 +545,19 @@ def writefile_Peaklist(outputprefixfilename, Data_array, overwrite=1,
         (peak_X, peak_Y, _, peak_I, peak_fwaxmaj, peak_fwaxmin, peak_inclination,
             Xdev, Ydev, peak_bkg, Ipixmax, ) = Data_array.T
 
+    elif nbcolumns == 3: # basic X, Y , I
+        # need to set fake data
+        (peak_X, peak_Y, peak_I) = Data_array.T
+        (peak_fwaxmaj, peak_fwaxmin, peak_inclination,
+        Xdev, Ydev, peak_bkg) =  np.zeros((6, nbpeaks))
+        Ipixmax = 500*np.ones(nbpeaks)
+
     outputfile = open(os.path.join(dirname, outputfilename), "w")
 
     outputfile.write("peak_X peak_Y peak_Itot peak_Isub peak_fwaxmaj peak_fwaxmin "
                                                 "peak_inclination Xdev Ydev peak_bkg Ipixmax\n")
 
-    if longueur == 1:
+    if nbpeaks == 1:
         print("nbcolumns", nbcolumns)
 
         outputfile.write(
@@ -578,7 +592,7 @@ def writefile_Peaklist(outputprefixfilename, Data_array, overwrite=1,
                                 Ydev.round(decimals=2),
                                 peak_bkg.round(decimals=2),
                                 Ipixmax))[i]
-                    ) for i in list(range(longueur))]))
+                    ) for i in list(range(nbpeaks))]))
         nbpeaks = len(peak_X)
 
     outputfile.write("\n# File created at %s with IOLaueTools.py" % (time.asctime()))
@@ -592,7 +606,7 @@ def writefile_Peaklist(outputprefixfilename, Data_array, overwrite=1,
     outputfile.close()
 
     print("table of %d peak(s) with %d columns has been written in \n%s"
-        % (longueur, nbcolumns, os.path.join(os.path.abspath(dirname), outputfilename)))
+        % (nbpeaks, nbcolumns, os.path.join(os.path.abspath(dirname), outputfilename)))
 
     return os.path.join(os.path.abspath(dirname), outputfilename)
 
@@ -1711,8 +1725,8 @@ def writefilegnomon(gnomonx, gnomony, outputfilename, dataselected):
     """
     linestowrite = []
     linestowrite.append(["gnomonx gnomony 2theta chi I #spot"])
-    longueur = len(gnomonx)
-    for i in list(range(longueur)):
+    nb = len(gnomonx)
+    for i in list(range(nb)):
         linestowrite.append([str(gnomonx[i]),
                             str(gnomony[i]),
                             str(2.0 * dataselected[0][i]),
@@ -1795,17 +1809,20 @@ def createselecteddata(tupledata_theta_chi_I, _listofselectedpts, _indicespotmax
     return (_dataselected, _nbmax)
 
 
-def ReadSpec(fname, scan):
+def ReadSpec(fname, scan, outputdate=False):
     """
     Procedure very based on that of Vincent Favre Nicolin procedure
+
+    return :
+    scan title = spec command (str), dict of data (key=counter name, val= values), [data (str)]
     """
     f = open(fname, "r")
 
-    s = "#S %i" % scan
+    s = "#S %d" % scan
     title = 0
 
     bigmca = []
-
+    # spec command with motors, steps and exposure
     while 1:
         title = f.readline()
         if s == title[0 : len(s)]:
@@ -1813,6 +1830,17 @@ def ReadSpec(fname, scan):
         if len(title) == 0:
             break
     print(title)
+    # date -----------------
+    date = 'unknown'
+    s = "#D"
+    while 1:
+        line = f.readline()
+        if s == line[0:len(s)]:
+            date = line[3:]
+            break
+        if len(line) == 0:
+            break
+    # data   (dict with key= counter column name) -------------
     s = "#L"
     coltit = 0
 
@@ -1887,8 +1915,10 @@ def ReadSpec(fname, scan):
             a[j] = d[coltit[i]][j]
         d[coltit[i]] = deepcopy(a)
     f.close()
-
-    return title, d
+    if outputdate:
+        return title, d, date
+    else:
+        return title, d
 
 
 # --- -----  read write Parameters file
